<?php

namespace common\logic\Producer\Producer\Service;

use common\logic\AbstractService;
use common\logic\Producer\Producer\Model\Producer;
use common\logic\ManagerInterface;
use common\logic\Producer\Producer\Repository\ProducerRepository;
use common\logic\Setting\AdminSettingBag;

class ProducerManager extends AbstractService implements ManagerInterface
{
    protected AdminSettingBag $adminSettingBag;
    protected ProducerRepository $producerRepository;

    public function loadDependencies(): void
    {
        $this->adminSettingBag = $this->loadService(AdminSettingBag::class);
        $this->producerRepository = $this->loadService(ProducerRepository::class);
    }

    public function sendEmailNewProducer(Producer $producer): void
    {
        \Yii::$app->mailerService->sendAdmin(
            'Nouveau producteur',
            'new-producer',
            [
                'producer' => $producer
            ]
        );
    }

    public function isProducerSignupOpen(): bool
    {
        return $this->adminSettingBag->get('maximumNumberProducers')
            > $this->producerRepository->countCacheProducersActiveWithTurnover();
    }

    public function getProducerSignupRemainingPlaces(): int
    {
        return max($this->adminSettingBag->get('maximumNumberProducers')
            - $this->producerRepository->countCacheProducersActiveWithTurnover(), 0);
    }
}